@@ -1,22 +1,18 @@
-# -*- coding: utf-8 -*-
+from __future__ import annotations
 
 import sys
 from os import path
 from pathlib import Path
-from typing import Optional
 
-if sys.version_info >= (3, 7):
-    import importlib.resources as ilr  # pragma: no cover
+# We use the new API introduced in Python 3.9, otherwise use the backport
+if sys.version_info >= (3, 9):
+    import importlib.resources as ilr
 else:
-    import importlib_resources as ilr  # pragma: no cover
+    import importlib_resources as ilr
 
 import click
 import typer
 
-from . import fonts as _fonts
-from . import icons as _icons
-from . import profiles as _profiles
-
 
 class ResourcePath:
     """Yields the path to a resource (just like importlib.resources.path), but can be used
@@ -29,32 +25,32 @@ class ResourcePath:
 
     def __enter__(self, *args, **kwargs) -> Path:
         assert self.context is None
-        self.context = ilr.path(self.package, self.resource)
-        return self.context.__enter__(*args, **kwargs)
+        self.context = ilr.path(self.package, self.resource)  # type: ignore
+        return self.context.__enter__(*args, **kwargs)  # type: ignore
 
-    def __exit__(self, *args, **kwargs) -> Optional[bool]:
+    def __exit__(self, *args, **kwargs) -> bool | None:
         try:
-            return self.context.__exit__(*args, **kwargs)
+            return self.context.__exit__(*args, **kwargs)  # type: ignore
         finally:
             self.context = None
 
 
 fonts = {
-    path.splitext(res)[0]: ResourcePath(_fonts, res)
-    for res in ilr.contents(_fonts)
-    if ilr.is_resource(_fonts, res) and res.endswith(".xml")
+    path.splitext(res.name)[0]: res
+    for res in (ilr.files(__package__) / "fonts").iterdir()
+    if res.is_file() and res.name.endswith(".ttf")
 }
 
 icons = {
-    path.splitext(res)[0]: ResourcePath(_icons, res)
-    for res in ilr.contents(_icons)
-    if ilr.is_resource(_icons, res) and res.endswith(".xml")
+    path.splitext(res.name)[0]: res
+    for res in (ilr.files(__package__) / "icons").iterdir()
+    if res.is_file() and res.name.endswith(".xml")
 }
 
 profiles = {
-    path.splitext(res)[0]: ResourcePath(_profiles, res)
-    for res in ilr.contents(_profiles)
-    if ilr.is_resource(_profiles, res) and res.endswith(".toml")
+    path.splitext(res.name)[0]: res
+    for res in (ilr.files(__package__) / "profiles").iterdir()
+    if res.is_file() and res.name.endswith(".toml")
 }
 
 
