@@ -1,6 +1,6 @@
-# -*- coding: utf-8 -*-
+from __future__ import annotations
 
-from typing import Any, NamedTuple, Optional
+from typing import Any, NamedTuple
 
 from . import Verbosity
 
@@ -11,7 +11,7 @@ class _Config(NamedTuple):
     show_align: bool
     dpi: int
     profile: bool
-    color: Optional[bool]
+    color: bool | None
     verbosity: Verbosity
     raise_warnings: bool
     is_script: bool
@@ -41,6 +41,7 @@ def set_config(**kwargs: Any) -> None:
 
     if _config is None:
         reset_config()  # pragma: no cover
+        assert _config is not None  # For the sake of intellisense
 
     _config = _Config(
         show_align=kwargs.pop("show_align", _config.show_align),
